Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(333)

Unified Diff: tests/corelib/splay_tree_from_iterable_test.dart

Issue 18072004: Add fromIterable(s) constructors in SplayTreeMap and LinkedHashMap. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Removed long line. Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tests/corelib/splay_tree_from_iterable_test.dart
diff --git a/tests/corelib/map_from_iterable_test.dart b/tests/corelib/splay_tree_from_iterable_test.dart
similarity index 64%
copy from tests/corelib/map_from_iterable_test.dart
copy to tests/corelib/splay_tree_from_iterable_test.dart
index 4d0468db66a48f55f4dbe162491cb47d5b90355b..18d0106930dc3d6f90f84ef8cab479e2ab3f6f76 100644
--- a/tests/corelib/map_from_iterable_test.dart
+++ b/tests/corelib/splay_tree_from_iterable_test.dart
@@ -16,10 +16,11 @@ main() {
}
void defaultFunctionValuesTest() {
- var map = new Map.fromIterable([1, 2, 3]);
+ var map = new SplayTreeMap.fromIterable([1, 2, 3]);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
@@ -31,10 +32,11 @@ void defaultFunctionValuesTest() {
}
void defaultKeyFunctionTest() {
- var map = new Map.fromIterable([1, 2, 3], value: (x) => x + 1);
+ var map = new SplayTreeMap.fromIterable([1, 2, 3], value: (x) => x + 1);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
@@ -46,10 +48,11 @@ void defaultKeyFunctionTest() {
}
void defaultValueFunctionTest() {
- var map = new Map.fromIterable([1, 2, 3], key: (x) => x + 1);
+ var map = new SplayTreeMap.fromIterable([1, 2, 3], key: (x) => x + 1);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
@@ -61,12 +64,12 @@ void defaultValueFunctionTest() {
}
void noDefaultValuesTest() {
- var map = new Map.fromIterable([1, 2, 3],
+ var map = new SplayTreeMap.fromIterable([1, 2, 3],
key: (x) => x + 1, value: (x) => x - 1);
-
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(3, map.length);
Expect.equals(3, map.keys.length);
@@ -78,9 +81,11 @@ void noDefaultValuesTest() {
}
void emptyIterableTest() {
- var map = new Map.fromIterable([]);
+ var map = new SplayTreeMap.fromIterable([]);
+
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(0, map.length);
Expect.equals(0, map.keys.length);
@@ -88,10 +93,11 @@ void emptyIterableTest() {
}
void equalElementsTest() {
- var map = new Map.fromIterable([1, 2, 2], key: (x) => x + 1);
+ var map = new SplayTreeMap.fromIterable([1, 2, 2], key: (x) => x + 1);
Expect.isTrue(map is Map);
- Expect.isTrue(map is HashMap);
+ Expect.isTrue(map is SplayTreeMap);
+ Expect.isFalse(map is HashMap);
Expect.equals(2, map.length);
Expect.equals(2, map.keys.length);
@@ -102,11 +108,12 @@ void equalElementsTest() {
}
void genericTypeTest() {
- var map = new Map<int, String>.fromIterable([1, 2, 3], value: (x) => '$x');
+ var map = new SplayTreeMap<int, String>.fromIterable([1, 2, 3], value: (x) => '$x');
Expect.isTrue(map is Map<int, String>);
+ Expect.isTrue(map is SplayTreeMap<int, String>);
- // Make sure it is not just Map<dynamic, dynamic>.
- Expect.isFalse(map is Map<String, dynamic>);
- Expect.isFalse(map is Map<dynamic, int>);
+ // Make sure it is not just SplayTreeMap<dynamic, dynamic>.
+ Expect.isFalse(map is SplayTreeMap<String, dynamic>);
+ Expect.isFalse(map is SplayTreeMap<dynamic, int>);
}
« no previous file with comments | « tests/corelib/linked_hash_map_from_iterables_test.dart ('k') | tests/corelib/splay_tree_from_iterables_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698